@@ -1,3 +1,110 @@
+#' Map country-level data.
+#' 
+#' Draw a map of country-level data, allowing countries to be coloured, from an
+#' object created in \code{\link{joinCountryData2Map}}.
+#' 
+#' Certain catMethod and colourPalette options go well together. e.g.
+#' "diverging" and "diverging", "categorical" and "rainbow"
+#' 
+#' There are two styles of legend available.  If catMethod='categorical' or the
+#' packages fields and spam are not installed a simple legend with coloured
+#' boxes is created. Otherwise a colour bar legend is created. Finer control
+#' can be achieved by \code{\link{addMapLegendBoxes}} or
+#' \code{\link{addMapLegend}} repectively.
+#' 
+#' @param mapToPlot a spatial polygons dataframe from joinCountryData2Map()
+#' containing country polygons and data, if none specified an internal example
+#' data is used
+#' @param nameColumnToPlot name of column containing the data you want to plot
+#' @param numCats number of categories to put the data in, may be modified if
+#' this number is incompatible with the catMethod chosen
+#' @param xlim map extents c(west,east), can be overidden by mapRegion
+#' @param ylim map extents c(south,north), can be overidden by mapRegion
+#' @param mapRegion a country name from getMap()[['NAME']] or
+#' 'world','africa','oceania','eurasia','uk' sets map extents, overrides
+#' xlim,ylim
+#' @param catMethod method for categorisation of data : \enumerate{
+#' \item "categorical" - each unique value is treated as a separate category
+#' \item for numeric data : "pretty", "fixedWidth", "diverging",
+#' "logFixedWidth", "quantiles" \item a numeric vector defining breaks e.g.
+#' c(0:5), note that a value of 2 goes into 1-2 not 2-3, uses
+#' cut(include.lowest=TRUE) }
+#' @param colourPalette string describing the colour palette to use, choice of:
+#' \enumerate{ \item "palette" for the current palette \item a vector of valid
+#' colours, e.g. =c('red','white','blue') or output from RColourBrewer \item one
+#' of "heat", "diverging", "white2Black", "black2White", "topo", "rainbow",
+#' "terrain", "negpos8", "negpos9" }
+#' @param addLegend whether to add a legend or not
+#' @param borderCol the colour for country borders
+#' @param mapTitle title to add to the map, any string or 'columnName' to set
+#' it to the name of the data column
+#' @param oceanCol a colour for the ocean
+#' @param aspect aspect for the map, defaults to 1, if set to 'variable' uses
+#' same method as plot.Spatial in sp
+#' @param missingCountryCol a colour for missing countries
+#' @param add whether to add this map on top of an existing map, TRUE/FALSE
+#' @param nameColumnToHatch allows hatching of country fills (e.g. to represent
+#' uncertainty) , specify a column containing numeric data , highest values
+#' will be solid and lower values will have a decreasing density of hatching ,
+#' new feature more documentation will be added soon
+#' @param lwd line width for country borders
+#' @return invisibly returns a list containing the data and main options used
+#' for the map, the list can be passed to \code{\link{addMapLegend}} or
+#' \code{\link{addMapLegendBoxes}} along with additional options to allow
+#' greater flexibility in legend creation.
+#' @section Warning: will generate unhelpful errors in data categorisation if
+#' inappropriate options are chosen, e.g. with catMethod:Quantiles if numCats
+#' too high so that unique breaks cannot be defined.
+#' @author andy south
+#' @seealso classInt, RColorBrewer
+#' @keywords aplot
+#' @examples
+#' 
+#' mapCountryData()
+#' data("countryExData",envir=environment(),package="rworldmap")
+#' sPDF <- joinCountryData2Map(countryExData
+#'               , joinCode = "ISO3"
+#'               , nameJoinColumn = "ISO3V10"
+#'               )
+#' mapCountryData( sPDF
+#'               , nameColumnToPlot="BIODIVERSITY" 
+#'               )
+#'               
+#' #user defined map colour scheme for categorical data              
+#' mapParams <- mapCountryData(nameColumnToPlot='GEO3major'
+#'               , catMethod='categorical'
+#'               , addLegend='FALSE'
+#'               , colourPalette=c('white','green','red','yellow','blue','black') 
+#'               )
+#' #changing legendText
+#' mapParams$legendText <- c('antarctic','africa','oceania'
+#'                          ,'americas','s.asia','eurasia')              
+#' do.call( addMapLegendBoxes, c(mapParams,x='bottom',title="Region",horiz=TRUE))
+#' 
+#' ##showing how rworldmap can be used with the classInt and RColorBrewer packages
+#' library(classInt)
+#' library(RColorBrewer)
+#' #getting example data and joining to a map
+#' data("countryExData",envir=environment(),package="rworldmap")
+#' sPDF <- joinCountryData2Map(countryExData,joinCode = "ISO3"
+#'                            ,nameJoinColumn = "ISO3V10")
+#' #getting class intervals using a 'jenks' classification in classInt package
+#' classInt <- classIntervals( sPDF$EPI, n=5, style="jenks")
+#' catMethod = classInt$brks
+#' #getting a colour scheme from the RColorBrewer package
+#' colourPalette <- brewer.pal(5,'RdPu')
+#' #calling mapCountryData with the parameters from classInt and RColorBrewer
+#' mapParams <- mapCountryData( sPDF, nameColumnToPlot="EPI", addLegend=FALSE
+#'                            , catMethod = catMethod, colourPalette=colourPalette )
+#' do.call(addMapLegend, c(mapParams
+#'                        ,legendLabels="all"
+#'                        ,legendWidth=0.5
+#'                        ,legendIntervals="data"))
+#' 
+#'               
+#' 
+#' 
+#' @export mapCountryData
 mapCountryData <- function(
                 mapToPlot =         ""
               , nameColumnToPlot =  ""
@@ -20,12 +127,6 @@ mapCountryData <- function(
                            
   functionName <- as.character(sys.call()[[1]])
                            
-  #browser()  #n to enter the step through debugger, Q to exit
-  
-  #29/9/2012 to avoid a polypath error, needs sp version >= 0.9-101 
-  #added usePolypath=FALSE in plot calls because safer and should work now
-  #set_Polypath(FALSE)
-  
 
   #28/6/2013 refactoring
   new <- TRUE
@@ -55,7 +156,6 @@ mapCountryData <- function(
   } #end of replaced bit 28/6/2013
   
   ## setting a default nameColumnToPlot if it isn't set
-  # moved out of above loop replaced by rwmCheckAndLoadInput
   if ( nameColumnToPlot == "" ) nameColumnToPlot <- "POP_EST" #  
   
   ## check that the column name exists in the data frame
@@ -67,7 +167,7 @@ mapCountryData <- function(
   ##classify data into categories   
   dataCategorised <- mapToPlot@data[[nameColumnToPlot]]
 
-  #30/5/12 if the data are not numerical then set catMethod to categorical
+  #if data are not numeric then set catMethod to categorical
   if ( ! is.numeric(dataCategorised) && catMethod != "categorical" )
      {
      catMethod = "categorical"
@@ -107,11 +207,6 @@ mapCountryData <- function(
   mapToPlot@data[[colNameCat]] <- dataCategorised     
   
   ## how many colours : numCats may be overriden (e.g. for 'pretty') 	
-  #5/11/12 issue that numCOlours got from the data
-  #so difficult to keep constant between plots
-  #move it further up so I can control it
-  #numColours <- length(levels(dataCategorised))
-  
   ## get vector of the colours to be used in map (length=num categories)    
   colourVector <- rwmGetColours(colourPalette,numColours)
   
@@ -126,8 +221,6 @@ mapCountryData <- function(
     dataCatNums[is.na(dataCatNums)]<-length(colourVector)
   }
 
-  #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-  #need to check this
   #Scale hatching variable (and invert). Then threshold above a certain value to secure solid status
   hatchVar = NULL
   if (nameColumnToHatch=='')
@@ -135,12 +228,10 @@ mapCountryData <- function(
       #setting up the map plot
       if (!add) rwmNewMapPlot(mapToPlot,mapRegion=mapRegion,xlim=xlim,ylim=ylim,oceanCol=oceanCol,aspect=aspect)
       #plotting the map
-      #plot(mapToPlot,col=colourVector[dataCatNums],border=borderCol,add=TRUE)#,density=c(20:200))#angle=c(1:360),)
       plot(mapToPlot, col=colourVector[dataCatNums], border=borderCol, add=TRUE, usePolypath=FALSE, lwd=lwd)#29/9/2012
       } else  
     {
     #*HATCHING OPTION*
-    #setting up the map plot    
      
       hatchVar = mapToPlot@data[[nameColumnToHatch]]
       
@@ -154,8 +245,6 @@ mapCountryData <- function(
       #setting up the map plot
       if(!add)  rwmNewMapPlot(mapToPlot,mapRegion=mapRegion,xlim=xlim,ylim=ylim,oceanCol=oceanCol,aspect=aspect)
       #plotting the map
-      #plot(mapToPlot,col=colourVector[mapToPlot@data$dataCatNums],border=borderCol,add=TRUE, density=hatchVar, angle=135, lty=1)
-      #plot(mapToPlot,col=colourVector[mapToPlot@data$dataCatNums],border=borderCol,add=TRUE, density=hatchVar, angle=45, lty=1)
       plot(mapToPlot,col=colourVector[dataCatNums],border=borderCol, density=hatchVar, angle=135, lty=1,add=TRUE,usePolypath=FALSE, lwd=lwd)#29/9/2012
       plot(mapToPlot,col=colourVector[dataCatNums],border=borderCol, density=hatchVar, angle=45, lty=1,add=TRUE,usePolypath=FALSE, lwd=lwd)#29/9/2012
                  
@@ -165,8 +254,7 @@ mapCountryData <- function(
 
   if (addLegend){
       
-      #if((length(catMethod)==1 && catMethod=="categorical") || !require("spam") || !require("fields")){
-      #20/8/13 removed require bits
+
 			if((length(catMethod)==1 && catMethod=="categorical") ){
       
         # simpler legend for categorical data OR if you don't have packages spam or fields.
@@ -174,7 +262,7 @@ mapCountryData <- function(
       
       }else{
         #colour bar legend based on fields package
-        addMapLegend(cutVector=cutVector,colourVector=colourVector,catMethod=catMethod) # ,plottedData=mapToPlot@data[[nameColumnToPlot]],catMethod=catMethod,colourPalette=colourPalette)
+        addMapLegend(cutVector=cutVector,colourVector=colourVector) #,catMethod=catMethod) # ,plottedData=mapToPlot@data[[nameColumnToPlot]],catMethod=catMethod,colourPalette=colourPalette)
       }  
   
   } #end of addLegend
