@@ -1,3 +1,75 @@
+#' Produce maps of global gridded data at half degree resolution
+#' 
+#' Produce maps of global gridded data at half degree resolution
+#' 
+#' Plots a map of global half degree gridded data, allowing classification,
+#' colours and regions to be set.
+#' 
+#' Certain catMethod and colourPalette options go well together. e.g.
+#' "diverging" and "diverging", "categorical" and "rainbow"
+#' 
+#' @param dataset gridded data either as a : \enumerate{ \item
+#' SpatialGridDataFrame (R object defined in package sp) \item file name of a
+#' GridAscii file - this is an Esri format \item 2D R matrix or array (rows by
+#' columns) }
+#' @param nameColumnToPlot name of column containing the data to plot
+#' @param numCats number of categories to put the data in, may be overidden if
+#' catMethod ='pretty'
+#' @param catMethod method for categorisation of data "pretty",
+#' "fixedWidth","diverging", "logFixedWidth","quantiles","categorical", or a
+#' numeric vector defining breaks
+#' @param colourPalette a string describing the colour palette to use, choice
+#' of : \enumerate{ \item "palette" for the current palette \item a vector of
+#' valid colours, e.g. =c('red','white','blue') or output from RColourBrewer
+#' \item one of "heat", "diverging", "white2Black", "black2White", "topo",
+#' "rainbow", "terrain", "negpos8", "negpos9" }
+#' @param xlim map extents c(west,east), can be overidden by mapRegion
+#' @param ylim map extents c(south,north), can be overidden by mapRegion
+#' @param mapRegion a country name from getMap()[['NAME']] or
+#' 'world','africa','oceania','eurasia','uk' sets map extents, overrides
+#' xlim,ylim
+#' @param addLegend whether to add a legend or not
+#' @param addBorders options for country borders, 'low','coarse' = low or
+#' coarse resolution, 'coasts' = coasts only, 'none' or NA for none
+#' @param borderCol the colour for country borders
+#' @param oceanCol a colour for the ocean if the grid values are NA
+#' @param landCol a colour to fill countries if the grid values are NA over
+#' land
+#' @param plotData whether to plotData, if FALSE a legend can be added on its
+#' own
+#' @param aspect aspect for the map, defaults to 1, if set to 'variable' uses
+#' same method as plot.Spatial in sp
+#' @param lwd line width for country borders
+#' @return invisibly returns a list containing the data and main options used
+#' for the map, the list can be passed to \code{\link{addMapLegend}} along with
+#' additional options to allow greater flexibility in legend creation.
+#' @author andy south
+#' @importFrom maptools readAsciiGrid
+#' @seealso classInt, RColorBrewer
+#' @keywords hplot
+#' @examples
+#' 
+#' ## mapping continuous data
+#' data(gridExData,envir=environment(),package="rworldmap")
+#' gridExData <- get("gridExData")
+#' mapGriddedData(gridExData)
+#' 
+#' ## reclassing continuous data to categorical & mapping
+#' data(gridExData,envir=environment(),package="rworldmap")
+#' #find quartile breaks
+#' cutVector <- quantile(gridExData@@data[,1],na.rm=TRUE)
+#' #classify the data to a factor
+#' gridExData@@data$categories <- cut( gridExData@@data[,1]
+#'                                       , cutVector, include.lowest=TRUE)
+#' #rename the categories
+#' levels(gridExData@@data$categories) <- c('low', 'med', 'high', 'vhigh')
+#' #mapping
+#' mapGriddedData( gridExData, nameColumnToPlot= 'categories'
+#'               , catMethod='categorical')
+#' 
+#' 
+#' 
+#' @export mapGriddedData
 mapGriddedData <- function(
                            dataset =          ""
                          , nameColumnToPlot = "" 
@@ -23,8 +95,6 @@ mapGriddedData <- function(
 
     functionName <- as.character(sys.call()[[1]])
 
-    #require(maptools)
-    #require(sp)
     
     ## filename or nothing ##
     if (class(dataset)=='character')
@@ -139,8 +209,8 @@ mapGriddedData <- function(
       #12/10/10 moved into non-categorical loop from below
       sGDF$indexToPlot <- as.numeric( as.character( dataCategorised )) 
       #cut : labels for the levels of the resulting category.  By default,
-      #    labels are constructed using "(a,b]" interval notation.
-      #    If labels = FALSE, simple integer codes are returned instead of a factor.
+      #    labels are constructed using ?"(a,b]"? interval notation.
+      #    If ?labels = FALSE?, simple integer codes are returned instead of a factor.
       
       #13/11/10 fixing breaks difference between categorical and non-categorical
       breaks <- c(0:(length(cutVector)-1) )
@@ -188,9 +258,6 @@ mapGriddedData <- function(
        plot( getMap(resolution='coarse'), add=TRUE, border=borderCol, lwd=lwd )
        } else
     if (addBorders=='coasts'){
-       #30/9/2012 replacing use of maps library
-       #library(maps) 
-       #map(interior=FALSE,add=TRUE, col=borderCol )
        data(coastsCoarse,envir=environment(),package="rworldmap")
        coastsCoarse <- get("coastsCoarse")
        plot(coastsCoarse, add=TRUE, col=borderCol, lwd=lwd ) 
@@ -211,7 +278,7 @@ mapGriddedData <- function(
          
       }else{
         #colour bar legend based on fields package
-        addMapLegend(colourVector=colourVector,cutVector=cutVector,plottedData=sGDF[[attrName]],catMethod=catMethod,colourPalette=colourPalette)   
+        addMapLegend(colourVector=colourVector,cutVector=cutVector) #,plottedData=sGDF[[attrName]],catMethod=catMethod,colourPalette=colourPalette)   
         }
       }
 
