@@ -1,5 +1,12 @@
-`rworldmapExamples` <-
-function()
+#' Example code for plot creation
+#' 
+#' Example code to demonstrate creation of a series of plots
+#' 
+#' 
+#' @author andy south
+#' @keywords aplot
+#' @export rworldmapExamples
+rworldmapExamples <- function()
    {  
     #displays examples - i should probably put somewhere else
     
